==> training-token-generator-1.1.0.tgz: package/bin/index.js <==
#!/usr/bin/env node

import enquirer from 'enquirer'
import byuOAuth from 'byu-wabs-oauth'
import clipboardy from 'clipboardy'

;(async function () {
  const args = process.argv.slice(2) // there is always at least 2, due to 'node' and 'index'. We only care about anything after that.
  printBold('BYU-OIT Training Token Generator\n')
  if (args.length === 0 && !process.env.stage && !process.env.clientId && !process.env.clientSecret) {
    printBold('For faster usage, run `node index [dev/prod] [your client id] [your client secret]`')
    printBold('Alternatively, see the readme for storing these as env variables\n')
  }
  let stage, clientId, clientSecret
  if (args.length > 0) { // default to arguments if provided
    stage = args[0].toLowerCase()
  } else if (process.env.stage) { // then check for env variables
    stage = process.env.stage.toLowerCase()
  } else {
    const tog = new enquirer.Toggle({
      disabled: 'Sandbox',
      enabled: 'Production',
      message: 'Please select your environment (toggle with arrow keys)'
    })
    stage = await tog.run() ? 'prod' : 'dev'
  }
  if (stage === 'prd' || stage === 'production' || stage === 'stable') { // this logic is to verify the env and cli args
    stage = 'prod'
  }
  if (args.length > 1) {
    clientId = args[1]
  } else if (process.env.clientId) {
    clientId = process.env.clientId
  } else {
    const res = await enquirer.prompt({
      type: 'input',
      name: 'response',
      message: 'Please enter your Client Id'
    })
    clientId = res.response
  }
  if (args.length > 2) {
    clientSecret = args[2]
  } else if (process.env.clientSecret) {
    clientSecret = process.env.clientSecret
  } else {
    const res = await enquirer.prompt({
      type: 'password',
      name: 'response',
      message: 'Please enter your Client Secret'
    })
    clientSecret = res.response
  }
  try {
    const host = stage === 'prod' ? 'api.byu.edu' : 'api-sandbox.byu.edu'
    const oauth = await byuOAuth(clientId, clientSecret, { host })
    const token = await oauth.getClientGrantToken()
    printBold(`${stage === 'prod' ? 'PRODUCTION' : 'SANDBOX'} TOKEN:\n`)
    printBold(token.accessToken)
    printBold('\nIt expires in one hour from now (at ' + token.expiresAt + ')')
  } catch (e) {
    if (e.message.includes('Unable to get access token')) {
      printBold('Unable to get token. Things to check:')
      printBold('* Make sure you have entered in your Client Id and Secret in correctly')
      printBold('* Make sure that your stage matches your credentials (e.g. you need Sandbox credentials to generate a token in the Sandbox environment)')
      printBold('* If using CLI arguments, make sure you are following the right order (env, client id, client secret)')
      process.exit(-1)
    } else {
      throw e
    }
  }
  printBold(`${stage === 'prod' ? 'PRODUCTION' : 'SANDBOX'} TOKEN:\n`)
  printBold(token.accessToken + '\n')
  const copy = new enquirer.Toggle({
    disabled: 'No',
    enabled: 'Yes',
    message: 'Copy to your Clipboard? (toggle with arrow keys)'
  })
  const wantToCopy = args.length > 3 && ['yes','y','true'].includes(args[3].toLowerCase())
  if (wantToCopy || await copy.run()) { //the toggle will return true of they select 'Yes'
    clipboardy.writeSync(token.accessToken);
    printBold('\nThe token has been successfully copied to your clipboard')
  } else {
    printBold('\nYou will have to copy the token manually from above when you are ready.')
  }
  printBold('\nIt expires in one hour from now (at ' + token.expiresAt + ')')
  process.exit(0)
})()

function printBold(string) { // used to mimic the text style used by 'enquirer'
  console.log('\x1b[1m%s\x1b[0m', string)
}

==> training-token-generator-1.3.0.tgz: package/bin/index.js <==
#!/usr/bin/env node

import enquirer from 'enquirer'
import byuOAuth from 'byu-wabs-oauth'
import clipboard from 'clipboardy'
import fs from 'fs'

;(async function () {
  const args = process.argv.slice(2) // there is always at least 2, due to 'node' and 'index'. We only care about anything after that.
  printBold('BYU-OIT Training Token Generator\n')
  if (args.length === 0 && !process.env.stage && !process.env.clientId && !process.env.clientSecret) {
    printBold('For faster usage, run `node index [dev/prod] [your client id] [your client secret]`')
    printBold('Alternatively, see the readme for storing these as env variables\n')
  }
  let stage, clientId, clientSecret
  if (args.length > 0) { // default to arguments if provided
    stage = args[0].toLowerCase()
    if (['--version','-v','-version'].includes(stage)) {
      console.log('Version: ' + await getVersion())
      process.exit(0)
    }
    if (['--help','-h','-help'].includes(stage)) {
      console.log('Find usage and information here: https://github.com/byu-oit/training-token-generator#readme')
      process.exit(0)
    }
  } else if (process.env.stage) { // then check for env variables
    stage = process.env.stage.toLowerCase()
  } else {
    const tog = new enquirer.Toggle({
      disabled: 'Sandbox',
      enabled: 'Production',
      message: 'Please select your environment (toggle with arrow keys)'
    })
    stage = await tog.run() ? 'prod' : 'dev'
  }
  if (stage === 'prd' || stage === 'production' || stage === 'stable') { // this logic is to verify the env and cli args
    stage = 'prod'
  }
  if (args.length > 1) {
    clientId = args[1]
  } else if (process.env.clientId) {
    clientId = process.env.clientId
  } else {
    const res = await enquirer.prompt({
      type: 'input',
      name: 'response',
      message: 'Please enter your Client Id'
    })
    clientId = res.response
  }
  if (args.length > 2) {
    clientSecret = args[2]
  } else if (process.env.clientSecret) {
    clientSecret = process.env.clientSecret
  } else {
    const res = await enquirer.prompt({
      type: 'password',
      name: 'response',
      message: 'Please enter your Client Secret'
    })
    clientSecret = res.response
  }
  try {
    const host = stage === 'prod' ? 'api.byu.edu' : 'api-sandbox.byu.edu'
    const oauth = await byuOAuth(clientId, clientSecret, { host })
    const token = await oauth.getClientGrantToken()
    printBold(`${stage === 'prod' ? 'PRODUCTION' : 'SANDBOX'} TOKEN:\n`)
    printBold(token.accessToken)
    printBold('\nIt expires in one hour from now (at ' + token.expiresAt + ')')
  } catch (e) {
    if (e.message.includes('Unable to get access token')) {
      printBold('Unable to get token. Things to check:')
      printBold('* Make sure you have entered in your Client Id and Secret in correctly')
      printBold('* Make sure that your stage matches your credentials (e.g. you need Sandbox credentials to generate a token in the Sandbox environment)')
      printBold('* If using CLI arguments, make sure you are following the right order (env, client id, client secret)')
      process.exit(-1)
    } else {
      throw e
    }
  }
  printBold(`${stage === 'prod' ? 'PRODUCTION' : 'SANDBOX'} TOKEN:\n`)
  printBold(token.accessToken + '\n')
  const copy = new enquirer.Toggle({
    disabled: 'No',
    enabled: 'Yes',
    message: 'Copy to your Clipboard? (toggle with arrow keys)'
  })
  const wantToCopy = args.length > 3 && ['yes','y','true'].includes(args[3].toLowerCase())
  if (wantToCopy || await copy.run()) { //the toggle will return true of they select 'Yes'
    clipboard.writeSync(token.accessToken);
    printBold('\nThe token has been successfully copied to your clipboard')
  } else {
    printBold('\nYou will have to copy the token manually from above when you are ready.')
  }
  printBold('\nIt expires in one hour from now (at ' + token.expiresAt + ')')
  process.exit(0)
})()

function printBold(string) { // used to mimic the text style used by 'enquirer'
  console.log('\x1b[1m%s\x1b[0m', string)
}

async function getVersion() {
  // there are normally easier ways to do this with require but I can't figure out a simpler way to do it with an ES6 module
  const data = JSON.parse(fs.readFileSync('./package.json'))
  return data.version
}
